pub fn subtree_range(lines: &[&str], line: usize) -> Option<(usize, usize)>Expand description
The [start, end) line range of the subtree rooted at line — the headline
plus every following line until the next headline of the same or higher level
(a smaller or equal star count). None if line is not a headline.